@@ -31,6 +31,7 @@ module Pipes.Prelude (
     -- * Consumers
     -- $consumers
     , stdoutLn
+    , mapM_
     , print
     , toHandle
     , drain
@@ -45,6 +46,7 @@ module Pipes.Prelude (
     , filterM
     , take
     , takeWhile
+    , takeWhile'
     , drop
     , dropWhile
     , concat
@@ -55,6 +57,7 @@ module Pipes.Prelude (
     , chain
     , read
     , show
+    , seq
 
     -- * Folds
     -- $folds
@@ -117,6 +120,7 @@ import Prelude hiding (
     , length
     , map
     , mapM
+    , mapM_
     , maximum
     , minimum
     , notElem
@@ -128,6 +132,7 @@ import Prelude hiding (
     , readLn
     , sequence
     , show
+    , seq
     , sum
     , take
     , takeWhile
@@ -232,6 +237,16 @@ stdoutLn = go
            Right () -> go
 {-# INLINABLE stdoutLn #-}
 
+-- | Consume all values using a monadic function
+mapM_ :: Monad m => (a -> m ()) -> Consumer' a m r
+mapM_ f = for cat (\a -> lift (f a))
+{-# INLINABLE mapM_ #-}
+
+{-# RULES
+    "p >-> mapM_ f" forall p f .
+        p >-> mapM_ f = for p (\a -> lift (f a))
+  #-}
+
 -- | 'print' values to 'IO.stdout'
 print :: (MonadIO m, Show a) => Consumer' a m r
 print = for cat (\a -> liftIO (Prelude.print a))
@@ -403,6 +418,25 @@ takeWhile predicate = go
             else return ()
 {-# INLINABLE takeWhile #-}
 
+{-| @(takeWhile' p)@ is a version of takeWhile that returns the value failing
+    the predicate.
+
+> takeWhile' (pure True) = cat
+>
+> takeWhile' (liftA2 (&&) p1 p2) = takeWhile' p1 >-> takeWhile' p2
+-}
+takeWhile' :: Monad m => (a -> Bool) -> Pipe a a m a
+takeWhile' predicate = go
+  where
+    go = do
+        a <- await
+        if (predicate a)
+            then do
+                yield a
+                go
+            else return a
+{-# INLINABLE takeWhile' #-}
+
 {-| @(drop n)@ discards @n@ values going downstream
 
 > drop 0 = cat
@@ -532,6 +566,11 @@ show :: (Monad m, Show a) => Pipe a String m r
 show = map Prelude.show
 {-# INLINABLE show #-}
 
+-- | Evaluate all values flowing downstream to WHNF
+seq :: Monad m => Pipe a a m r
+seq = for cat $ \a -> yield $! a
+{-# INLINABLE seq #-}
+
 {- $folds
     Use these to fold the output of a 'Producer'.  Many of these folds will stop
     drawing elements if they can compute their result early, like 'any':
@@ -755,15 +794,11 @@ toList = loop
     memory.
 -}
 toListM :: Monad m => Producer a m () -> m [a]
-toListM = loop
+toListM = fold step begin done
   where
-    loop p = case p of
-        Request v _  -> closed v
-        Respond a fu -> do
-            as <- loop (fu ())
-            return (a:as)
-        M         m  -> m >>= loop
-        Pure    _    -> return []
+    step x a = x . (a:)
+    begin = id
+    done x = x []
 {-# INLINABLE toListM #-}
 
 -- | Zip two 'Producer's
